/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License, Version 1.0 only
 * (the "License").  You may not use this file except in compliance
 * with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */
/*
 * Copyright 2014 Garrett D'Amore <garrett@damore.org>
 */
/*	Copyright (c) 1984, 1986, 1987, 1988, 1989 AT&T	*/
/*	  All Rights Reserved  	*/


#ifndef	_SYSLOG_H
#define	_SYSLOG_H

#include <features.h>
#include <sys/syslog.h>
#include <sys/va_list.h>

#ifndef LOG_PERROR
#define LOG_PERROR 0x20
#endif

#define LOG_PRI(p) ((p) & LOG_PRIMASK)
#define LOG_MAKEPRI(fac, pri) ((fac) | (pri))


#ifdef SYSLOG_NAMES
#define INTERNAL_NOPRI 0x10
#define INTERNAL_MARK LOG_MAKEPRI(LOG_NFACILITIES << 3, 0)

typedef struct _code
{
    char    *c_name;
    int c_val;
} CODE;

CODE prioritynames[] =
{
    {"alert", LOG_ALERT},
    {"crit", LOG_CRIT},
    {"debug", LOG_DEBUG},
    {"emerg", LOG_EMERG},
    {"err", LOG_ERR},
    {"error", LOG_ERR},
    {"info", LOG_INFO},
    {"none", INTERNAL_NOPRI},
    {"notice", LOG_NOTICE},
    {"panic", LOG_EMERG},
    {"warn", LOG_WARNING},
    {"warning", LOG_WARNING},
    {NULL, -1}
};
CODE facilitynames[] =
{
    {"auth", LOG_AUTH},
    {"authpriv", LOG_AUTHPRIV},
    {"cron", LOG_CRON},
    {"daemon", LOG_DAEMON},
    {"ftp", LOG_FTP},
    {"kern", LOG_KERN},
    {"lpr", LOG_LPR},
    {"mail", LOG_MAIL},
    {"mark", INTERNAL_MARK},
    {"news", LOG_NEWS},
    {"security", LOG_AUTH},
    {"syslog", LOG_SYSLOG},
    {"user", LOG_USER},
    {"uucp", LOG_UUCP},
    {"local0", LOG_LOCAL0},
    {"local1", LOG_LOCAL1},
    {"local2", LOG_LOCAL2},
    {"local3", LOG_LOCAL3},
    {"local4", LOG_LOCAL4},
    {"local5", LOG_LOCAL5},
    {"local6", LOG_LOCAL6},
    {"local7", LOG_LOCAL7},
    {NULL, -1}
};

#endif


#ifdef	__cplusplus
extern "C" {
#endif

void openlog(const char *, int, int);
void syslog(int, const char *, ...);
void closelog(void);
int setlogmask(int);
#if !defined(_XPG4_2) || defined(__EXTENSIONS__)
void vsyslog(int, const char *, __va_list);
#endif	/* !defined(_XPG4_2) || defined(__EXTENSIONS__) */

#ifdef	__cplusplus
}
#endif

#endif	/* _SYSLOG_H */
